#ifdef GL_ES
precision mediump float;
#endif

uniform float u_time;
uniform vec2 u_resolution;

vec2 mulComplex(vec2 x, vec2 y)
{
  return vec2(x.x * y.x - x.y * y.y, x.x * y.y + x.y * y.x);
}

vec2 mandelbrotIteration(vec2 z, vec2 c)
{
  return mulComplex(z, z) + c;
}
vec3 calculateMandelbrot(vec2 c) 
{
  vec2 z = vec2(0);
  vec3 col = vec3(0);
  for (int i = 0; i < 8; i++) {
    z = mandelbrotIteration(z, c);
    float n = .1 / (1. + .1 * float(- i));
    if (length(z - .1 * vec2(sin(u_time),cos(u_time))) < .5 + .3 * sin(.2 + u_time + c.x * 2.)) {
      col = col + vec3(n, .0, .0);
    }
    if (length(z - .1*vec2(sin(u_time + 2.09), cos(u_time + 2.09))) < .5 + .3 * sin(.2 + u_time + c.x * 2.)) {
      col = col + vec3(.0, n, .0);
    }
    if (length(z - .1*vec2(sin(u_time + 4.19), cos(u_time + 4.19))) < .5 + .3 * sin(.2 + u_time + c.x * 2.)) {
      col = col + vec3(.0, .0, n);
    }
  }
  return col;
}

void mainImage( out vec4 fragColor, in vec2 fragCoord )
{
  // Normalized pixel coordinates (from 0 to 1)
  vec2 uv = (fragCoord - .5 * u_resolution.xy)/min(u_resolution.x, u_resolution.y);
  uv = uv * 3.;
  uv.x -= .8; 
  vec3 mandelbrot = calculateMandelbrot(uv);
  fragColor = vec4(mandelbrot, 1.);
}

void main() {
    mainImage(gl_FragColor, gl_FragCoord.xy);
}
